'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var PropTypes = require('prop-types');
var styled = require('styled-components');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);
var styled__default = /*#__PURE__*/_interopDefaultLegacy(styled);

const circle = (color, size = '8px') => styled.css`
  width: ${size};
  height: ${size};
  border-radius: 50%;
  background-color: ${color};
`;

const circleMixin = (color, size = '8px') => styled.css`
  content: "";
  display: block;
  position: absolute;
  ${circle(color, size)}
`;

const AvatarWrapper = styled__default['default'].div`
  position: relative;
`;
const StatusIcon = styled__default['default'].div`
  position: absolute;
  left: 2px;
  top: 4px;

  &::before {
    ${circleMixin('white')};
    transform: scale(2)
  }

  &::after {
    ${({
  theme,
  status,
  size
}) => {
  if (status === 'online') {
    return circleMixin(theme.green, size);
  }

  return circleMixin(theme.gray, size);
}}
  }
`;
const AvatarClip = styled__default['default'].div`
    width: ${({
  size
}) => size};
    height: ${({
  size
}) => size};
    border-radius: 50%;
    overflow: hidden;
`;
const AvatarImage = styled__default['default'].img`
    width: 100%;
    height: 100%;
    object-position: center
`;

function Avatar({
  src,
  size = '48px',
  status,
  StatusIconSize = '8px',
  ...rest
}) {
  return /*#__PURE__*/React__default['default'].createElement(AvatarWrapper, rest, status && /*#__PURE__*/React__default['default'].createElement(StatusIcon, {
    status: status,
    size: StatusIconSize
  }), /*#__PURE__*/React__default['default'].createElement(AvatarClip, {
    size: size
  }, /*#__PURE__*/React__default['default'].createElement(AvatarImage, {
    src: src,
    alt: ""
  })));
}

Avatar.propTypes = {
  src: PropTypes__default['default'].string.isRequired,
  size: PropTypes__default['default'].string,
  status: PropTypes__default['default'].oneOf(['online', 'offline']),
  StatusIconSize: PropTypes__default['default'].string
};
Avatar.defaultProps = {
  size: '48px',
  status: 'online',
  StatusIconSize: '8px'
};

exports.Avatar = Avatar;
